@@ -3,6 +3,7 @@
 import json
 import os
 import io
+import six
 import sys
 import shutil
 import jinja2
@@ -123,13 +124,14 @@ class LogToHtml(object):
         }
 
         for item in step["__children__"]:
-            if item["data"]["name"] == "try_log_screen" and isinstance(item["data"].get("ret"), str):
+            if item["data"]["name"] == "try_log_screen" and isinstance(item["data"].get("ret", None), six.text_type):
                 src = item["data"]['ret']
-                if self.export_dir:
+                if self.export_dir:  # all relative path
                     src = os.path.join(LOGDIR, src)
+                    screen['_filepath'] = src
                 else:
-                    src = os.path.join(self.log_root, src)
-                screen['src'] = src
+                    screen['_filepath'] = os.path.abspath(os.path.join(self.log_root, src))
+                screen['src'] = screen['_filepath']
                 break
 
         display_pos = None
@@ -161,7 +163,6 @@ class LogToHtml(object):
 
         if display_pos:
             screen["pos"].append(display_pos)
-
         return screen
 
     def _translate_traceback(self, step):
@@ -185,17 +186,14 @@ class LogToHtml(object):
         for k, arg in enumerate(args):
             value = arg["value"]
             if isinstance(value, dict) and value.get("__class__") == "Template":
-                image_path = str(value['filename'])
-                if not self.export_dir:
-                    if os.path.isfile(os.path.join(self.script_root, image_path)):
-                        image_path = os.path.join(self.script_root, image_path)
-                    else:
-                        image_path = value['_filepath']
-                else:
+                if self.export_dir:  # all relative path
+                    image_path = value['filename']
                     if not os.path.isfile(os.path.join(self.script_root, image_path)):
-                        shutil.copy(value['_filepath'], self.script_root)
+                        shutil.copy(value['_filepath'], self.script_root)  # copy image used by using statement
+                else:
+                    image_path = os.path.abspath(value['_filepath'])
                 arg["image"] = image_path
-                crop_img = screen = imread(image_path)
+                crop_img = imread(value['_filepath'])
                 arg["resolution"] = get_resolution(crop_img)
         return code
 
@@ -237,7 +235,7 @@ class LogToHtml(object):
             "touch": lambda: u"点击 %s" % (u"目标图片" if isinstance(args['v'], dict) else u"屏幕坐标 %s" % args['v']),
             "swipe": u"滑动操作",
             "wait": u"等待目标图片出现",
-            "exists": lambda: u"图片%s存在" % ("" if res else "不"),
+            "exists": lambda: u"图片%s存在" % ("" if res else u"不"),
             "text": lambda: u"输入文字:%s" % args.get('text'),
             "keyevent": lambda: u"点击[%s]按键" % args.get('keyname'),
             "sleep": lambda: u"等待%s秒" % args.get('secs'),
